@@ -1,8 +1,6 @@
-from functools import partial
-from types import new_class
-from typing import Any, Callable, Generic, Iterator, Mapping, TypeVar
-
-from frozendict import frozendict
+from collections.abc import Callable, Iterator, Mapping
+from types import MappingProxyType, new_class
+from typing import Any, Generic, TypeVar
 
 __all__ = ("Lazy", "LazyMapping")
 
@@ -20,9 +18,9 @@ class Lazy(Generic[T]):
         self.__factory = factory
         self.__value = _sentinel
 
-    def __setattr__(self, name: str, value: Any):
+    def __setattr__(self, name: str, value: Any, /):
         if self.is_set:
-            raise TypeError(f"`{repr(self)}` is frozen.")
+            raise TypeError(f"`{self}` is frozen.")
 
         return super().__setattr__(name, value)
 
@@ -47,13 +45,12 @@ class Lazy(Generic[T]):
 class LazyMapping(Mapping[K, V]):
     __slots__ = ("__lazy",)
 
-    __lazy: Lazy[frozendict[K, V]]
+    __lazy: Lazy[MappingProxyType[K, V]]
 
     def __init__(self, iterator: Iterator[tuple[K, V]]):
-        factory = partial(frozendict, iterator)
-        self.__lazy = Lazy(factory)
+        self.__lazy = Lazy(lambda: MappingProxyType(dict(iterator)))
 
-    def __getitem__(self, key: K) -> V:
+    def __getitem__(self, key: K, /) -> V:
         return self.__lazy.value[key]
 
     def __iter__(self) -> Iterator[K]:
